pytest-bdd-html
===============

Version: 0.1.7rc0

A ``pytest`` plugin to display `BDD <https://en.wikipedia.org/wiki/Behavior-driven_development>`_ info in the ``pytest-html``-generated HTML test report.

Depends on ``pytest-bdd`` and ``pytest-html``.

To use it, just install it. There will be a new 3rd column with label "Description".

Options
-------
Available command line options:

* ``--bdd-html-css=PATH``: specify a path to custom CSS for styling the Description column
  
CSS classes
-----------
TBD
